<?PHP
/*
 * AlijaCoursePlugin.class.php - AlijaCourse plugin for Stud.IP
 * Copyright (c) 2007  Elmar Ludwig
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */

// require flexi templates
require_once 'vendor/flexi/flexi.php';

require_once 'lib/classes/Token.class.php';
require_once 'AlijaData.php';

/**
 * PHP class for Alija course plugin
 */
class AlijaCoursePlugin extends AbstractStudIPStandardPlugin
{
    var $alija_data;
    var $template_factory;

    function AlijaCoursePlugin ()
    {
        parent::AbstractStudIPStandardPlugin();

        $this->alija_data = new AlijaData($this->getId());
        $this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates/');

        $user = $this->getUser();
        $permission = $user->getPermission();

        // this plugin wants its own icon
        $this->setPluginIconName("images/icon.gif");
        $this->setChangeIndicatorIconName('images/icon_red.gif');

        // navigation
        $navigation = new PluginNavigation();
        $navigation->setDisplayname($this->getDisplaytitle());
        $navigation->addLinkParam('action', 'main');

        if ($permission->hasTutorPermissionInPOI())
        {
            $config_nav = new PluginNavigation();
            $config_nav->setDisplayname(_('Einstellungen'));
            $config_nav->addLinkParam('action', 'config');
            $navigation->addSubmenu($config_nav);
        }

        $this->setNavigation($navigation);
        $this->setShownInOverview(true);
    }

    function initialize ()
    {
        global $HELP_KEYWORD;

        $HELP_KEYWORD = 'AlijaCourse';
    }

    function getPluginname ()
    {
        return 'AlijaCourse';
    }

    function getDisplaytitle ()
    {
        $title = $this->alija_data->getTitle();

        return $title != '' ? $title : $this->getPluginname();
    }

    function actionShow ()
    {
        $action = $_REQUEST['action'];

        switch ($action)
        {
            case 'config':
                $this->editConfig();
                break;

            default:
                $this->display();
        }
    }

    function actionShowDescriptionalPage ()
    {
        // ABSOLUTE_URI_STUDIP is not available in 1.2-os1
        if (isset($GLOBALS['ABSOLUTE_URI_STUDIP']))
            $ABSOLUTE_URI_STUDIP = $GLOBALS['ABSOLUTE_URI_STUDIP'];
        else
            $ABSOLUTE_URI_STUDIP = 'http://'.$GLOBALS['EXTERN_SERVER_NAME'];

        $template = $this->template_factory->open('info');
        $template->set_attribute('plugin_url', $ABSOLUTE_URI_STUDIP.$this->getPluginPath());
        $template->set_attribute('installation_id', $GLOBALS['STUDIP_INSTALLATION_ID']);

        echo $template->render();

        parent::actionShowDescriptionalPage();
    }

    function display ()
    {
        // ABSOLUTE_URI_STUDIP is not available in 1.2-os1
        if (isset($GLOBALS['ABSOLUTE_URI_STUDIP']))
            $ABSOLUTE_URI_STUDIP = $GLOBALS['ABSOLUTE_URI_STUDIP'];
        else
            $ABSOLUTE_URI_STUDIP = 'http://'.$GLOBALS['EXTERN_SERVER_NAME'];

        // get new token valid for 1 hour
        $user = $this->getUser();
        $token = new Token($user->getUserid(), 3600);

        $external_url = $this->alija_data->getUrl();
        $validate_url = sprintf('%s%s/validate.php?token=%s', $ABSOLUTE_URI_STUDIP,
                                $this->getPluginPath(), $token->get_token());

        $template = $this->template_factory->open('display');
        $template->set_attribute('content', $this->alija_data->getContent());
        $template->set_attribute('chuser', $this->alija_data->getUser());
        $template->set_attribute('chdate', $this->alija_data->getChangeDate());
        $template->set_attribute('external_url', $external_url);
        $template->set_attribute('validate_url', $validate_url);

        echo $template->render();
    }

    function editConfig ()
    {
        $user = $this->getUser();
        $permission = $user->getPermission();

        if (!$permission->hasTutorPermissionInPOI())
        {
            StudIPTemplateEngine::showErrorMessage(_('Sie besitzen keine Berechtigung, um dieses Plugin zu konfigurieren.'));
            return;
        }

        if (isset($_REQUEST['save']) || isset($_REQUEST['save_x']))
        {
            // remove magic quotes
            $title = stripslashes($_REQUEST['title']);
            $content = stripslashes($_REQUEST['content']);
            $url = stripslashes($_REQUEST['url']);

            $this->alija_data->setTitle($title);
            $this->alija_data->setContent($content);
            $this->alija_data->setURL($url);
            $this->alija_data->setUser($user->getUserid());
            $this->alija_data->store();
        }

        $template = $this->template_factory->open('config');
        $template->set_attribute('title', $this->alija_data->getTitle());
        $template->set_attribute('content', $this->alija_data->getContent());
        $template->set_attribute('url', $this->alija_data->getURL());
        $template->set_attribute('plugin', $this);

        echo $template->render();
    }

    function hasChanged ($lastlogin)
    {
        // needed because id is initialized too late on overview page
        $this->alija_data = new AlijaData($this->getId());

        return $lastlogin < $this->alija_data->getChangeDate();
    }

    function setActivated ($active)
    {
        parent::setActivated($active);

        if (!$active && $this->alija_data->getCourse() != '' && $this->alija_data->getChangeDate())
        {
            $this->alija_data->delete();
        }
    }

    // Note: has_changed is optional in Stud.IP 1.5
    function getOverviewMessage ($has_changed = false)
    {
        return $this->getDisplaytitle().($has_changed ? ' '._('gendert') : '');
    }

    function getPluginExistingItems ($range_id)
    {
        return $this->alija_data->getChangeDate() ? 1 : 0;
    }
}
?>
